# McAfee ePolicy Orchestrator (ePO) DXL Python Service
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

## Overview

The [McAfee ePolicy Orchestrator](https://www.mcafee.com/us/products/epolicy-orchestrator.aspx) (ePO) DXL Python
service exposes access to ePO's remote commands via the [Data Exchange Layer](http://www.mcafee.com/us/solutions/data-exchange-layer.aspx) (DXL) fabric.

The purpose of this service is to allow users to invoke ePO remote commands via the DXL fabric.

## Documentation

See the [Wiki](https://github.com/opendxl/opendxl-epo-service-python/wiki) for an overview of the McAfee
ePolicy Orchestrator (ePO) DXL Python service and usage examples.

See the [ePolicy Orchestrator (ePO) DXL Python service documentation](https://opendxl.github.io/opendxl-epo-service-python/pydoc) for
installation instructions, API documentation, and usage examples.

## Installation

To start using the McAfee ePolicy Orchestrator (ePO) DXL Python Service:

* Download the [Latest Release](https://github.com/opendxl/opendxl-epo-service-python/releases/latest)
* Extract the release .zip file
* View the `README.html` file located at the root of the extracted files.
  * The `README` links to the documentation which includes installation instructions and usage examples.

## Bugs and Feedback

For bugs, questions and discussions please use the [GitHub Issues](https://github.com/opendxl/opendxl-epo-service-python/issues).

## LICENSE

Copyright 2017 McAfee, Inc.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
